@@ -61,14 +61,30 @@ class FrogMLAuthClient:
             response.raise_for_status()  # Raises an HTTPError for bad responses
             response_data: dict = response.json()
 
-            if "serverId" not in response_data:
-                raise login_exception
-
-            self._tenant_id = response_data["serverId"]
+            if "serverId" in response_data:
+                self._tenant_id = response_data["serverId"]
+            else:
+                self.__get_jpd_id(base_url)
 
         except (requests.exceptions.RequestException, ValueError) as exc:
             raise login_exception from exc
 
+    def __get_jpd_id(self, base_url: str):
+        url: str = urljoin(base_url, "/jfconnect/api/v1/system/jpd_id")
+        headers: dict = {"Authorization": f"Bearer {self._token}"}
+        response = requests.get(url=url, headers=headers, timeout=15)
+
+        if response.status_code == 200:
+            self._tenant_id = response.text
+        elif response.status_code == 401:
+            raise FrogmlLoginException(
+                "Failed to authenticate with JFrog. Please check your credentials"
+            )
+        else:
+            raise FrogmlLoginException(
+                "Failed to authenticate with JFrog. Please check your artifactory configuration"
+            )
+
     def validate_token(self: Self, token: Optional[str]):
         if token is None or len(token) <= self.__MIN_TOKEN_LENGTH or token.isspace():
             raise FrogmlLoginException(
