@@ -4,6 +4,8 @@ from datetime import datetime, timezone
 from enum import Enum
 from typing import Dict, List, Optional, Union
 
+from typing_extensions import Self
+
 from frogml.storage.artifactory import ArtifactoryApi, StartTransactionResponse
 from frogml.storage.authentication.models import AuthConfig
 from frogml.storage.authentication.utils import get_credentials
@@ -74,6 +76,11 @@ class FrogMLStorage(BaseStorage):
             max_workers=self.http_threads_count
         )
 
+    def get_repository_configuration(self: Self, repository_key: str):
+        return self.artifactory_api.get_repository_configuration(
+            repository_key=repository_key
+        )
+
     def upload_dataset_version(
         self,
         repository: str,
