@@ -4,8 +4,6 @@ from typing import Any, Generator, List, Tuple
 import grpc
 import pytest
 
-from frogml._proto.qwak.model_group.model_group_pb2_grpc import add_ModelGroupManagementServiceServicer_to_server
-from frogml.core.inner.di_configuration import FrogmlContainer
 from frogml._proto.jfml.model_version.v1.model_version_manager_service_pb2_grpc import (
     add_ModelVersionManagerServiceServicer_to_server,
 )
@@ -93,6 +91,7 @@ from frogml._proto.qwak.kube_deployment_captain.kube_deployment_captain_service_
 from frogml._proto.qwak.logging.log_reader_service_pb2_grpc import (
     add_LogReaderServiceServicer_to_server,
 )
+from frogml._proto.qwak.model_group.model_group_pb2_grpc import add_ModelGroupManagementServiceServicer_to_server
 from frogml._proto.qwak.models.models_pb2_grpc import (
     add_ModelsManagementServiceServicer_to_server,
 )
@@ -102,9 +101,7 @@ from frogml._proto.qwak.monitoring.v0.alerting_channel_management_service_pb2_gr
 from frogml._proto.qwak.offline.serving.v1.offline_serving_async_service_pb2_grpc import (
     add_FeatureStoreOfflineServingAsyncServiceServicer_to_server,
 )
-from frogml._proto.qwak.projects.projects_pb2_grpc import (
-    add_ProjectsManagementServiceServicer_to_server,
-)
+from frogml._proto.qwak.projects.projects_pb2_grpc import add_ProjectsManagementServiceServicer_to_server
 from frogml._proto.qwak.secret_service.secret_service_pb2_grpc import (
     add_SecretServiceServicer_to_server,
 )
@@ -114,6 +111,7 @@ from frogml._proto.qwak.self_service.user.v1.user_service_pb2_grpc import (
 from frogml._proto.qwak.service_discovery.service_discovery_location_service_pb2_grpc import (
     add_LocationDiscoveryServiceServicer_to_server,
 )
+from frogml.core.inner.di_configuration import FrogmlContainer
 from frogml_services_mock.mocks.alert_manager_service_api import (
     AlertManagerServiceApiMock,
 )
@@ -238,7 +236,6 @@ def frogml_container():
     from frogml.core.clients import model_group_management
     from frogml.core.clients import audience
     from frogml.core.clients import data_versioning
-    from frogml.core.clients import project
     from frogml.core.clients import logging_client
     from frogml.core.clients import automation_management
     from frogml.core.clients import file_versioning
@@ -268,7 +265,6 @@ def frogml_container():
             kube_deployment_captain,
             logging_client,
             model_management,
-            project,
             self_service,
             eco_system,
             user_application_instance,
